from django.test import TestCase

# Create your tests here.
from django.test.client import Client
from django.contrib.auth.models import User
from django.http import HttpResponse
import uuid

from ..status_code import *

class RegisterTest(TestCase):
    def setUp(self):
        self.client = Client()

        self.url: str = "/api/accounts/register"

        self.username: str = str(uuid.uuid4())
        self.password: str = str(uuid.uuid4())

    def test_normal_register(self):
        response: HttpResponse = self.client.post(self.url, {'username': self.username, 'password': self.password})
        response_text: str = response.content.decode('utf-8')
        self.assertEqual(USER_ADDED, response_text)

    def test_incomplet_form_no_username_no_password(self):
        response: HttpResponse = self.client.post(self.url)
        errors: dict = eval(response.content)
        errors_expected: dict = {'username': [USERNAME_MISSING], 'password': [PASSWORD_MISSING]}
        self.assertEqual(errors, errors_expected)

    def test_incomplet_form_no_password(self):
        response: HttpResponse = self.client.post(self.url,  {"username": self.username})
        errors: dict = eval(response.content)
        errors_expected: dict = {'password': [PASSWORD_MISSING]}
        self.assertEqual(errors, errors_expected)

    def test_incomplet_form_no_username(self):
        response: HttpResponse = self.client.post(self.url,  {"password": self.password})
        errors: dict = eval(response.content)
        errors_expected: dict = {}
        self.assertEqual(errors, errors_expected)
    
    def test_incomplet_form_no_username(self):
        response: HttpResponse = self.client.post(self.url,  {"password": self.password})
        errors: dict = eval(response.content)
        errors_expected: dict = {'username': [USERNAME_MISSING]}
        self.assertEqual(errors, errors_expected)

    def test_already_registered(self):
        User(username=self.username, password=self.password).save()
        response: HttpResponse = self.client.post(self.url, {'username': self.username, 'password': self.password})
        errors: dict = eval(response.content)
        errors_expected: dict = {'username': [USERNAME_ALREADY_USED]}
        self.assertEqual(errors, errors_expected)